# Bookmarks

Bookmarks are an easy way for a user to save certain 'favorite' assets that they want to reference.
Bookmarks can also be set from the [`Resources` service](https://mylibrary.aiod.eu/resources) in the web portal.
Bookmarks are private to the user, and to use any of the functions in this module [authentication](authentication.md) is required.


::: aiod.bookmarks
    options:
      members:
        - Bookmark
        - register
        - delete
        - get_list